# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_columnshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/counters_columnshard.proto\x12\x14NKikimr.NColumnShard\x1a\x1eydb/core/protos/counters.proto*\xc6\x12\n\x0f\x45SimpleCounters\x12 \n\x0e\x43OUNTER_TABLES\x10\x00\x1a\x0c\x82\xd6\x1b\x08\n\x06Tables\x12-\n\x15\x43OUNTER_TABLE_PRESETS\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cTablePresets\x12)\n\x13\x43OUNTER_TTL_PRESETS\x10\x02\x1a\x10\x82\xd6\x1b\x0c\n\nTtlPresets\x12\'\n\x12\x43OUNTER_TABLE_TTLS\x10\x03\x1a\x0f\x82\xd6\x1b\x0b\n\tTableTtls\x12\"\n\x0f\x43OUNTER_INDEXES\x10\x04\x1a\r\x82\xd6\x1b\t\n\x07Indexes\x12\x33\n\x18\x43OUNTER_PREPARED_RECORDS\x10\x05\x1a\x15\x82\xd6\x1b\x11\n\x0fPreparedRecords\x12/\n\x16\x43OUNTER_PREPARED_BYTES\x10\x06\x1a\x13\x82\xd6\x1b\x0f\n\rPreparedBytes\x12\x35\n\x19\x43OUNTER_COMMITTED_RECORDS\x10\x07\x1a\x16\x82\xd6\x1b\x12\n\x10\x43ommittedRecords\x12\x31\n\x17\x43OUNTER_COMMITTED_BYTES\x10\x08\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43ommittedBytes\x12,\n\x14\x43OUNTER_INDEX_TABLES\x10\t\x1a\x12\x82\xd6\x1b\x0e\n\x0cIndex/Tables\x12\x30\n\x16\x43OUNTER_INDEX_GRANULES\x10\n\x1a\x14\x82\xd6\x1b\x10\n\x0eIndex/Granules\x12;\n\x1c\x43OUNTER_INDEX_EMPTY_GRANULES\x10\x0b\x1a\x19\x82\xd6\x1b\x15\n\x13Index/EmptyGranules\x12\x45\n!COUNTER_INDEX_OVERLOADED_GRANULES\x10\x0c\x1a\x1e\x82\xd6\x1b\x1a\n\x18Index/OverloadedGranules\x12;\n\x1c\x43OUNTER_INDEX_COLUMN_RECORDS\x10\r\x1a\x19\x82\xd6\x1b\x15\n\x13Index/ColumnRecords\x12H\n#COUNTER_INDEX_COLUMN_METADATA_BYTES\x10\x0e\x1a\x1f\x82\xd6\x1b\x1b\n\x19Index/ColumnMetadataBytes\x12;\n\x19\x43OUNTER_INSERTED_PORTIONS\x10\x0f\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InsertedPortions\x12\x35\n\x16\x43OUNTER_INSERTED_BLOBS\x10\x10\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InsertedBlobs\x12\x33\n\x15\x43OUNTER_INSERTED_ROWS\x10\x11\x1a\x18\x82\xd6\x1b\x14\n\x12Index/InsertedRows\x12\x35\n\x16\x43OUNTER_INSERTED_BYTES\x10\x12\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InsertedBytes\x12<\n\x1a\x43OUNTER_INSERTED_RAW_BYTES\x10\x13\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InsertedBytesRaw\x12=\n\x1a\x43OUNTER_COMPACTED_PORTIONS\x10\x14\x1a\x1d\x82\xd6\x1b\x19\n\x17Index/CompactedPortions\x12\x37\n\x17\x43OUNTER_COMPACTED_BLOBS\x10\x15\x1a\x1a\x82\xd6\x1b\x16\n\x14Index/CompactedBlobs\x12\x35\n\x16\x43OUNTER_COMPACTED_ROWS\x10\x16\x1a\x19\x82\xd6\x1b\x15\n\x13Index/CompactedRows\x12\x37\n\x17\x43OUNTER_COMPACTED_BYTES\x10\x17\x1a\x1a\x82\xd6\x1b\x16\n\x14Index/CompactedBytes\x12>\n\x1b\x43OUNTER_COMPACTED_RAW_BYTES\x10\x18\x1a\x1d\x82\xd6\x1b\x19\n\x17Index/CompactedBytesRaw\x12H\n COUNTER_SPLIT_COMPACTED_PORTIONS\x10\x19\x1a\"\x82\xd6\x1b\x1e\n\x1cIndex/SplitCompactedPortions\x12\x42\n\x1d\x43OUNTER_SPLIT_COMPACTED_BLOBS\x10\x1a\x1a\x1f\x82\xd6\x1b\x1b\n\x19Index/SplitCompactedBlobs\x12@\n\x1c\x43OUNTER_SPLIT_COMPACTED_ROWS\x10\x1b\x1a\x1e\x82\xd6\x1b\x1a\n\x18Index/SplitCompactedRows\x12\x42\n\x1d\x43OUNTER_SPLIT_COMPACTED_BYTES\x10\x1c\x1a\x1f\x82\xd6\x1b\x1b\n\x19Index/SplitCompactedBytes\x12I\n!COUNTER_SPLIT_COMPACTED_RAW_BYTES\x10\x1d\x1a\"\x82\xd6\x1b\x1e\n\x1cIndex/SplitCompactedBytesRaw\x12;\n\x19\x43OUNTER_INACTIVE_PORTIONS\x10\x1e\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InactivePortions\x12\x35\n\x16\x43OUNTER_INACTIVE_BLOBS\x10\x1f\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InactiveBlobs\x12\x33\n\x15\x43OUNTER_INACTIVE_ROWS\x10 \x1a\x18\x82\xd6\x1b\x14\n\x12Index/InactiveRows\x12\x35\n\x16\x43OUNTER_INACTIVE_BYTES\x10!\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InactiveBytes\x12<\n\x1a\x43OUNTER_INACTIVE_RAW_BYTES\x10\"\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InactiveBytesRaw\x12*\n\x13\x43OUNTER_SCAN_IN_FLY\x10#\x1a\x11\x82\xd6\x1b\r\n\x0bScanTxInFly\x12\x39\n\x18\x43OUNTER_EVICTED_PORTIONS\x10$\x1a\x1b\x82\xd6\x1b\x17\n\x15Index/EvictedPortions\x12\x33\n\x15\x43OUNTER_EVICTED_BLOBS\x10%\x1a\x18\x82\xd6\x1b\x14\n\x12Index/EvictedBlobs\x12\x31\n\x14\x43OUNTER_EVICTED_ROWS\x10&\x1a\x17\x82\xd6\x1b\x13\n\x11Index/EvictedRows\x12\x33\n\x15\x43OUNTER_EVICTED_BYTES\x10\'\x1a\x18\x82\xd6\x1b\x14\n\x12Index/EvictedBytes\x12:\n\x19\x43OUNTER_EVICTED_RAW_BYTES\x10(\x1a\x1b\x82\xd6\x1b\x17\n\x15Index/EvictedBytesRaw\x12,\n\x15\x43OUNTER_WRITES_IN_FLY\x10)\x1a\x11\x82\xd6\x1b\r\n\x0bWritesInFly*\x85!\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00\x12-\n\x15\x43OUNTER_WRITE_SUCCESS\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cWriteSuccess\x12\'\n\x12\x43OUNTER_WRITE_FAIL\x10\x02\x1a\x0f\x82\xd6\x1b\x0b\n\tWriteFail\x12+\n\x14\x43OUNTER_READ_SUCCESS\x10\x03\x1a\x11\x82\xd6\x1b\r\n\x0bReadSuccess\x12%\n\x11\x43OUNTER_READ_FAIL\x10\x04\x1a\x0e\x82\xd6\x1b\n\n\x08ReadFail\x12\x31\n\x17\x43OUNTER_PREPARE_REQUEST\x10\x05\x1a\x14\x82\xd6\x1b\x10\n\x0ePrepareRequest\x12-\n\x15\x43OUNTER_PREPARE_ERROR\x10\x06\x1a\x12\x82\xd6\x1b\x0e\n\x0cPrepareError\x12\x31\n\x17\x43OUNTER_PREPARE_SUCCESS\x10\x07\x1a\x14\x82\xd6\x1b\x10\n\x0ePrepareSuccess\x12\x34\n\x19\x43OUNTER_PLAN_STEP_IGNORED\x10\x08\x1a\x15\x82\xd6\x1b\x11\n\x0fPlanStepIgnored\x12\x36\n\x1a\x43OUNTER_PLAN_STEP_ACCEPTED\x10\t\x1a\x16\x82\xd6\x1b\x12\n\x10PlanStepAccepted\x12+\n\x14\x43OUNTER_SCANNED_ROWS\x10\n\x1a\x11\x82\xd6\x1b\r\n\x0bScannedRows\x12-\n\x15\x43OUNTER_SCANNED_BYTES\x10\x0b\x1a\x12\x82\xd6\x1b\x0e\n\x0cScannedBytes\x12:\n\x1c\x43OUNTER_UPSERT_BLOBS_WRITTEN\x10\x0c\x1a\x18\x82\xd6\x1b\x14\n\x12UpsertBlobsWritten\x12:\n\x1c\x43OUNTER_UPSERT_BYTES_WRITTEN\x10\r\x1a\x18\x82\xd6\x1b\x14\n\x12UpsertBytesWritten\x12>\n\x1e\x43OUNTER_INDEXING_BLOBS_WRITTEN\x10\x0e\x1a\x1a\x82\xd6\x1b\x16\n\x14IndexingBlobsWritten\x12>\n\x1e\x43OUNTER_INDEXING_BYTES_WRITTEN\x10\x0f\x1a\x1a\x82\xd6\x1b\x16\n\x14IndexingBytesWritten\x12\x42\n COUNTER_COMPACTION_BLOBS_WRITTEN\x10\x10\x1a\x1c\x82\xd6\x1b\x18\n\x16\x43ompactionBlobsWritten\x12\x42\n COUNTER_COMPACTION_BYTES_WRITTEN\x10\x11\x1a\x1c\x82\xd6\x1b\x18\n\x16\x43ompactionBytesWritten\x12\x42\n COUNTER_BLOB_MANAGER_GC_REQUESTS\x10\x12\x1a\x1c\x82\xd6\x1b\x18\n\x16\x42lobManager/GcRequests\x12@\n\x1f\x43OUNTER_BLOB_MANAGER_KEEP_BLOBS\x10\x13\x1a\x1b\x82\xd6\x1b\x17\n\x15\x42lobManager/KeepBlobs\x12I\n$COUNTER_BLOB_MANAGER_DONT_KEEP_BLOBS\x10\x14\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x42lobManager/DontKeepBlobs\x12\x46\n\"COUNTER_BLOB_MANAGER_SKIPPED_BLOBS\x10\x15\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x42lobManager/SkippedBlobs\x12\x36\n\x1a\x43OUNTER_RAW_BYTES_UPSERTED\x10\x16\x1a\x16\x82\xd6\x1b\x12\n\x10RawBytesUpserted\x12\x31\n\x17\x43OUNTER_BLOBS_COMMITTED\x10\x17\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42lobsCommitted\x12\x31\n\x17\x43OUNTER_BYTES_COMMITTED\x10\x18\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42ytesCommitted\x12\x38\n\x1b\x43OUNTER_RAW_BYTES_COMMITTED\x10\x19\x1a\x17\x82\xd6\x1b\x13\n\x11RawBytesCommitted\x12\x44\n!COUNTER_INDEXING_PORTIONS_WRITTEN\x10\x1a\x1a\x1d\x82\xd6\x1b\x19\n\x17IndexingPortionsWritten\x12H\n#COUNTER_COMPACTION_PORTIONS_WRITTEN\x10\x1b\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x43ompactionPortionsWritten\x12S\n)COUNTER_SPLIT_COMPACTION_PORTIONS_WRITTEN\x10\x1c\x1a$\x82\xd6\x1b \n\x1eSplitCompactionPortionsWritten\x12M\n&COUNTER_SPLIT_COMPACTION_BLOBS_WRITTEN\x10\x1d\x1a!\x82\xd6\x1b\x1d\n\x1bSplitCompactionBlobsWritten\x12M\n&COUNTER_SPLIT_COMPACTION_BYTES_WRITTEN\x10\x1e\x1a!\x82\xd6\x1b\x1d\n\x1bSplitCompactionBytesWritten\x12;\n\x1c\x43OUNTER_PORTIONS_DEACTIVATED\x10\x1f\x1a\x19\x82\xd6\x1b\x15\n\x13PortionsDeactivated\x12\x35\n\x19\x43OUNTER_BLOBS_DEACTIVATED\x10 \x1a\x16\x82\xd6\x1b\x12\n\x10\x42lobsDeactivated\x12\x35\n\x19\x43OUNTER_BYTES_DEACTIVATED\x10!\x1a\x16\x82\xd6\x1b\x12\n\x10\x42ytesDeactivated\x12<\n\x1d\x43OUNTER_RAW_BYTES_DEACTIVATED\x10\"\x1a\x19\x82\xd6\x1b\x15\n\x13RawBytesDeactivated\x12\x31\n\x17\x43OUNTER_PORTIONS_ERASED\x10#\x1a\x14\x82\xd6\x1b\x10\n\x0ePortionsErased\x12+\n\x14\x43OUNTER_BLOBS_ERASED\x10$\x1a\x11\x82\xd6\x1b\r\n\x0b\x42lobsErased\x12+\n\x14\x43OUNTER_BYTES_ERASED\x10%\x1a\x11\x82\xd6\x1b\r\n\x0b\x42ytesErased\x12\x32\n\x18\x43OUNTER_RAW_BYTES_ERASED\x10&\x1a\x14\x82\xd6\x1b\x10\n\x0eRawBytesErased\x12\x33\n\x18\x43OUNTER_INDEXING_SUCCESS\x10\'\x1a\x15\x82\xd6\x1b\x11\n\x0fIndexingSuccess\x12-\n\x15\x43OUNTER_INDEXING_FAIL\x10(\x1a\x12\x82\xd6\x1b\x0e\n\x0cIndexingFail\x12\x37\n\x1a\x43OUNTER_COMPACTION_SUCCESS\x10)\x1a\x17\x82\xd6\x1b\x13\n\x11\x43ompactionSuccess\x12\x31\n\x17\x43OUNTER_COMPACTION_FAIL\x10*\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43ompactionFail\x12\x42\n COUNTER_SPLIT_COMPACTION_SUCCESS\x10+\x1a\x1c\x82\xd6\x1b\x18\n\x16SplitCompactionSuccess\x12<\n\x1d\x43OUNTER_SPLIT_COMPACTION_FAIL\x10,\x1a\x19\x82\xd6\x1b\x15\n\x13SplitCompactionFail\x12\x31\n\x17\x43OUNTER_CLEANUP_SUCCESS\x10-\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43leanupSuccess\x12+\n\x14\x43OUNTER_CLEANUP_FAIL\x10.\x1a\x11\x82\xd6\x1b\r\n\x0b\x43leanupFail\x12)\n\x13\x43OUNTER_TTL_SUCCESS\x10/\x1a\x10\x82\xd6\x1b\x0c\n\nTtlSuccess\x12#\n\x10\x43OUNTER_TTL_FAIL\x10\x30\x1a\r\x82\xd6\x1b\t\n\x07TtlFail\x12*\n\x14\x43OUNTER_OUT_OF_SPACE\x10\x31\x1a\x10\x82\xd6\x1b\x0c\n\nOutOfSpace\x12/\n\x16\x43OUNTER_SCAN_RESTARTED\x10\x32\x1a\x13\x82\xd6\x1b\x0f\n\rScanRestarted\x12\x38\n\x1b\x43OUNTER_READ_INDEX_GRANULES\x10\x33\x1a\x17\x82\xd6\x1b\x13\n\x11ReadIndexGranules\x12\x38\n\x1b\x43OUNTER_READ_INDEX_PORTIONS\x10\x34\x1a\x17\x82\xd6\x1b\x13\n\x11ReadIndexPortions\x12\x32\n\x18\x43OUNTER_READ_INDEX_BLOBS\x10\x35\x1a\x14\x82\xd6\x1b\x10\n\x0eReadIndexBlobs\x12\x30\n\x17\x43OUNTER_READ_INDEX_ROWS\x10\x36\x1a\x13\x82\xd6\x1b\x0f\n\rReadIndexRows\x12\x32\n\x18\x43OUNTER_READ_INDEX_BYTES\x10\x37\x1a\x14\x82\xd6\x1b\x10\n\x0eReadIndexBytes\x12\x31\n\x17\x43OUNTER_WRITE_DUPLICATE\x10\x38\x1a\x14\x82\xd6\x1b\x10\n\x0eWriteDuplicate\x12=\n\x1e\x43OUNTER_SMALL_BLOB_WRITE_COUNT\x10\x39\x1a\x19\x82\xd6\x1b\x15\n\x13SmallBlobWriteCount\x12=\n\x1e\x43OUNTER_SMALL_BLOB_WRITE_BYTES\x10:\x1a\x19\x82\xd6\x1b\x15\n\x13SmallBlobWriteBytes\x12?\n\x1f\x43OUNTER_SMALL_BLOB_READ_SUCCESS\x10;\x1a\x1a\x82\xd6\x1b\x16\n\x14SmallBlobReadSuccess\x12;\n\x1d\x43OUNTER_SMALL_BLOB_READ_ERROR\x10<\x1a\x18\x82\xd6\x1b\x14\n\x12SmallBlobReadError\x12;\n\x1d\x43OUNTER_SMALL_BLOB_READ_BYTES\x10=\x1a\x18\x82\xd6\x1b\x14\n\x12SmallBlobReadBytes\x12?\n\x1f\x43OUNTER_SMALL_BLOB_DELETE_COUNT\x10>\x1a\x1a\x82\xd6\x1b\x16\n\x14SmallBlobDeleteCount\x12?\n\x1f\x43OUNTER_SMALL_BLOB_DELETE_BYTES\x10?\x1a\x1a\x82\xd6\x1b\x16\n\x14SmallBlobDeleteBytes\x12\x44\n!COUNTER_EVICTION_PORTIONS_WRITTEN\x10@\x1a\x1d\x82\xd6\x1b\x19\n\x17\x45victionPortionsWritten\x12>\n\x1e\x43OUNTER_EVICTION_BLOBS_WRITTEN\x10\x41\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45victionBlobsWritten\x12>\n\x1e\x43OUNTER_EVICTION_BYTES_WRITTEN\x10\x42\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45victionBytesWritten\x12/\n\x16\x43OUNTER_EXPORT_SUCCESS\x10\x43\x1a\x13\x82\xd6\x1b\x0f\n\rExportSuccess\x12)\n\x13\x43OUNTER_EXPORT_FAIL\x10\x44\x1a\x10\x82\xd6\x1b\x0c\n\nExportFail\x12/\n\x16\x43OUNTER_FORGET_SUCCESS\x10\x45\x1a\x13\x82\xd6\x1b\x0f\n\rForgetSuccess\x12)\n\x13\x43OUNTER_FORGET_FAIL\x10\x46\x1a\x10\x82\xd6\x1b\x0c\n\nForgetFail\x12/\n\x16\x43OUNTER_WRITE_OVERLOAD\x10G\x1a\x13\x82\xd6\x1b\x0f\n\rWriteOverload\x12:\n\x1c\x43OUNTER_WRITE_OVERLOAD_SHARD\x10H\x1a\x18\x82\xd6\x1b\x14\n\x12WriteOverloadShard\x12-\n\x15\x43OUNTER_INDEXING_TIME\x10I\x1a\x12\x82\xd6\x1b\x0e\n\x0cIndexingTime\x12\x31\n\x17\x43OUNTER_COMPACTION_TIME\x10J\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43ompactionTime*\x86\x02\n\x13\x45PercentileCounters\x12+\n\x14\x43OUNTER_SCAN_LATENCY\x10\x00\x1a\x11\x82\xd6\x1b\r\n\x0bScanLatency\x1a\xc1\x01\x92\xd6\x1b\xbc\x01\x12\x07\x08\x90N\x12\x02\x31\x30\x12\x08\x08\xa0\x9c\x01\x12\x02\x32\x30\x12\x08\x08\xd0\x86\x03\x12\x02\x35\x30\x12\t\x08\xa0\x8d\x06\x12\x03\x31\x30\x30\x12\t\x08\xc0\x9a\x0c\x12\x03\x32\x30\x30\x12\t\x08\xa0\xc2\x1e\x12\x03\x35\x30\x30\x12\n\x08\xc0\x84=\x12\x04\x31\x30\x30\x30\x12\n\x08\x80\x89z\x12\x04\x32\x30\x30\x30\x12\x0b\x08\xc0\x96\xb1\x02\x12\x04\x35\x30\x30\x30\x12\x0c\x08\x80\xad\xe2\x04\x12\x05\x31\x30\x30\x30\x30\x12\x0c\x08\x80\xda\xc4\t\x12\x05\x32\x30\x30\x30\x30\x12\x0c\x08\x80\x8e\xce\x1c\x12\x05\x36\x30\x30\x30\x30\x12\r\x08\x80\x9c\x9c\x39\x12\x06\x31\x32\x30\x30\x30\x30\x12\x0e\x08\x80\xc6\x86\x8f\x01\x12\x06\x33\x30\x30\x30\x30\x30\x12\x0e\x08\x80\x8c\x8d\x9e\x02\x12\x06\x36\x30\x30\x30\x30\x30*\xf8\x04\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x01\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12.\n\x14TXTYPE_UPDATE_SCHEMA\x10\x02\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxUpdateSchema\x12\x1f\n\x0cTXTYPE_WRITE\x10\x03\x1a\r\x8a\xd6\x1b\t\n\x07TxWrite\x12\x1d\n\x0bTXTYPE_READ\x10\x04\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxRead\x12#\n\x0eTXTYPE_PROPOSE\x10\x05\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxPropose\x12*\n\x12TXTYPE_WRITE_INDEX\x10\x06\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxWriteIndex\x12%\n\x0fTXTYPE_PLANSTEP\x10\x07\x1a\x10\x8a\xd6\x1b\x0c\n\nTxPlanStep\x12;\n\x1bTXTYPE_NOTIFY_TX_COMPLETION\x10\x08\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxNotifyTxCompletion\x12\x30\n\x15TXTYPE_PROPOSE_CANCEL\x10\t\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxProposeCancel\x12%\n\x0fTXTYPE_PROGRESS\x10\n\x1a\x10\x8a\xd6\x1b\x0c\n\nTxProgress\x12(\n\x11TXTYPE_START_SCAN\x10\x0b\x1a\x11\x8a\xd6\x1b\r\n\x0bTxStartScan\x12\x33\n\x17TXTYPE_READ_BLOB_RANGES\x10\x0c\x1a\x16\x8a\xd6\x1b\x12\n\x10TxReadBlobRanges\x12!\n\rTXTYPE_EXPORT\x10\r\x1a\x0e\x8a\xd6\x1b\n\n\x08TxExport\x12!\n\rTXTYPE_FORGET\x10\x0e\x1a\x0e\x8a\xd6\x1b\n\n\x08TxForgetB\'\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0b\x43olumnShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_columnshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\013ColumnShard'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLES"]._serialized_options = b'\202\326\033\010\n\006Tables'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_PRESETS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_PRESETS"]._serialized_options = b'\202\326\033\016\n\014TablePresets'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TTL_PRESETS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TTL_PRESETS"]._serialized_options = b'\202\326\033\014\n\nTtlPresets'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_TTLS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_TTLS"]._serialized_options = b'\202\326\033\013\n\tTableTtls'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEXES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEXES"]._serialized_options = b'\202\326\033\t\n\007Indexes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_RECORDS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_RECORDS"]._serialized_options = b'\202\326\033\021\n\017PreparedRecords'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_BYTES"]._serialized_options = b'\202\326\033\017\n\rPreparedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_RECORDS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_RECORDS"]._serialized_options = b'\202\326\033\022\n\020CommittedRecords'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_BYTES"]._serialized_options = b'\202\326\033\020\n\016CommittedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_TABLES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_TABLES"]._serialized_options = b'\202\326\033\016\n\014Index/Tables'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_GRANULES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_GRANULES"]._serialized_options = b'\202\326\033\020\n\016Index/Granules'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_EMPTY_GRANULES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_EMPTY_GRANULES"]._serialized_options = b'\202\326\033\025\n\023Index/EmptyGranules'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_OVERLOADED_GRANULES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_OVERLOADED_GRANULES"]._serialized_options = b'\202\326\033\032\n\030Index/OverloadedGranules'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_RECORDS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_RECORDS"]._serialized_options = b'\202\326\033\025\n\023Index/ColumnRecords'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_METADATA_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_METADATA_BYTES"]._serialized_options = b'\202\326\033\033\n\031Index/ColumnMetadataBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_PORTIONS"]._serialized_options = b'\202\326\033\030\n\026Index/InsertedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BLOBS"]._serialized_options = b'\202\326\033\025\n\023Index/InsertedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_ROWS"]._serialized_options = b'\202\326\033\024\n\022Index/InsertedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BYTES"]._serialized_options = b'\202\326\033\025\n\023Index/InsertedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_RAW_BYTES"]._serialized_options = b'\202\326\033\030\n\026Index/InsertedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_PORTIONS"]._serialized_options = b'\202\326\033\031\n\027Index/CompactedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BLOBS"]._serialized_options = b'\202\326\033\026\n\024Index/CompactedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_ROWS"]._serialized_options = b'\202\326\033\025\n\023Index/CompactedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BYTES"]._serialized_options = b'\202\326\033\026\n\024Index/CompactedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_RAW_BYTES"]._serialized_options = b'\202\326\033\031\n\027Index/CompactedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_PORTIONS"]._serialized_options = b'\202\326\033\036\n\034Index/SplitCompactedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BLOBS"]._serialized_options = b'\202\326\033\033\n\031Index/SplitCompactedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_ROWS"]._serialized_options = b'\202\326\033\032\n\030Index/SplitCompactedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BYTES"]._serialized_options = b'\202\326\033\033\n\031Index/SplitCompactedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_RAW_BYTES"]._serialized_options = b'\202\326\033\036\n\034Index/SplitCompactedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_PORTIONS"]._serialized_options = b'\202\326\033\030\n\026Index/InactivePortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BLOBS"]._serialized_options = b'\202\326\033\025\n\023Index/InactiveBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_ROWS"]._serialized_options = b'\202\326\033\024\n\022Index/InactiveRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BYTES"]._serialized_options = b'\202\326\033\025\n\023Index/InactiveBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_RAW_BYTES"]._serialized_options = b'\202\326\033\030\n\026Index/InactiveBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SCAN_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SCAN_IN_FLY"]._serialized_options = b'\202\326\033\r\n\013ScanTxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_PORTIONS"]._serialized_options = b'\202\326\033\027\n\025Index/EvictedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BLOBS"]._serialized_options = b'\202\326\033\024\n\022Index/EvictedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_ROWS"]._serialized_options = b'\202\326\033\023\n\021Index/EvictedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BYTES"]._serialized_options = b'\202\326\033\024\n\022Index/EvictedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_RAW_BYTES"]._serialized_options = b'\202\326\033\027\n\025Index/EvictedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WRITES_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WRITES_IN_FLY"]._serialized_options = b'\202\326\033\r\n\013WritesInFly'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_SUCCESS"]._serialized_options = b'\202\326\033\016\n\014WriteSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_FAIL"]._serialized_options = b'\202\326\033\013\n\tWriteFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_SUCCESS"]._serialized_options = b'\202\326\033\r\n\013ReadSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_FAIL"]._serialized_options = b'\202\326\033\n\n\010ReadFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_REQUEST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_REQUEST"]._serialized_options = b'\202\326\033\020\n\016PrepareRequest'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_ERROR"]._serialized_options = b'\202\326\033\016\n\014PrepareError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS"]._serialized_options = b'\202\326\033\020\n\016PrepareSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_IGNORED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_IGNORED"]._serialized_options = b'\202\326\033\021\n\017PlanStepIgnored'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_ACCEPTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_ACCEPTED"]._serialized_options = b'\202\326\033\022\n\020PlanStepAccepted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_ROWS"]._serialized_options = b'\202\326\033\r\n\013ScannedRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_BYTES"]._serialized_options = b'\202\326\033\016\n\014ScannedBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\024\n\022UpsertBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\024\n\022UpsertBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024IndexingBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024IndexingBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\030\n\026CompactionBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\030\n\026CompactionBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_GC_REQUESTS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_GC_REQUESTS"]._serialized_options = b'\202\326\033\030\n\026BlobManager/GcRequests'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_KEEP_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_KEEP_BLOBS"]._serialized_options = b'\202\326\033\027\n\025BlobManager/KeepBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_DONT_KEEP_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_DONT_KEEP_BLOBS"]._serialized_options = b'\202\326\033\033\n\031BlobManager/DontKeepBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_SKIPPED_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_SKIPPED_BLOBS"]._serialized_options = b'\202\326\033\032\n\030BlobManager/SkippedBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_UPSERTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_UPSERTED"]._serialized_options = b'\202\326\033\022\n\020RawBytesUpserted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_COMMITTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_COMMITTED"]._serialized_options = b'\202\326\033\020\n\016BlobsCommitted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_COMMITTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_COMMITTED"]._serialized_options = b'\202\326\033\020\n\016BytesCommitted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_COMMITTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_COMMITTED"]._serialized_options = b'\202\326\033\023\n\021RawBytesCommitted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033\031\n\027IndexingPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033\033\n\031CompactionPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033 \n\036SplitCompactionPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\035\n\033SplitCompactionBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\035\n\033SplitCompactionBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_DEACTIVATED"]._serialized_options = b'\202\326\033\025\n\023PortionsDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_DEACTIVATED"]._serialized_options = b'\202\326\033\022\n\020BlobsDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_DEACTIVATED"]._serialized_options = b'\202\326\033\022\n\020BytesDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_DEACTIVATED"]._serialized_options = b'\202\326\033\025\n\023RawBytesDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_ERASED"]._serialized_options = b'\202\326\033\020\n\016PortionsErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_ERASED"]._serialized_options = b'\202\326\033\r\n\013BlobsErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_ERASED"]._serialized_options = b'\202\326\033\r\n\013BytesErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_ERASED"]._serialized_options = b'\202\326\033\020\n\016RawBytesErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_SUCCESS"]._serialized_options = b'\202\326\033\021\n\017IndexingSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_FAIL"]._serialized_options = b'\202\326\033\016\n\014IndexingFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_SUCCESS"]._serialized_options = b'\202\326\033\023\n\021CompactionSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_FAIL"]._serialized_options = b'\202\326\033\020\n\016CompactionFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_SUCCESS"]._serialized_options = b'\202\326\033\030\n\026SplitCompactionSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_FAIL"]._serialized_options = b'\202\326\033\025\n\023SplitCompactionFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_SUCCESS"]._serialized_options = b'\202\326\033\020\n\016CleanupSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_FAIL"]._serialized_options = b'\202\326\033\r\n\013CleanupFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_SUCCESS"]._serialized_options = b'\202\326\033\014\n\nTtlSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_FAIL"]._serialized_options = b'\202\326\033\t\n\007TtlFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_OUT_OF_SPACE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_OUT_OF_SPACE"]._serialized_options = b'\202\326\033\014\n\nOutOfSpace'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCAN_RESTARTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCAN_RESTARTED"]._serialized_options = b'\202\326\033\017\n\rScanRestarted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_GRANULES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_GRANULES"]._serialized_options = b'\202\326\033\023\n\021ReadIndexGranules'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_PORTIONS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_PORTIONS"]._serialized_options = b'\202\326\033\023\n\021ReadIndexPortions'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BLOBS"]._serialized_options = b'\202\326\033\020\n\016ReadIndexBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_ROWS"]._serialized_options = b'\202\326\033\017\n\rReadIndexRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BYTES"]._serialized_options = b'\202\326\033\020\n\016ReadIndexBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_DUPLICATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_DUPLICATE"]._serialized_options = b'\202\326\033\020\n\016WriteDuplicate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_COUNT"]._serialized_options = b'\202\326\033\025\n\023SmallBlobWriteCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_BYTES"]._serialized_options = b'\202\326\033\025\n\023SmallBlobWriteBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_SUCCESS"]._serialized_options = b'\202\326\033\026\n\024SmallBlobReadSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_ERROR"]._serialized_options = b'\202\326\033\024\n\022SmallBlobReadError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_BYTES"]._serialized_options = b'\202\326\033\024\n\022SmallBlobReadBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_COUNT"]._serialized_options = b'\202\326\033\026\n\024SmallBlobDeleteCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_BYTES"]._serialized_options = b'\202\326\033\026\n\024SmallBlobDeleteBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033\031\n\027EvictionPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024EvictionBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024EvictionBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_SUCCESS"]._serialized_options = b'\202\326\033\017\n\rExportSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_FAIL"]._serialized_options = b'\202\326\033\014\n\nExportFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_SUCCESS"]._serialized_options = b'\202\326\033\017\n\rForgetSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_FAIL"]._serialized_options = b'\202\326\033\014\n\nForgetFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD"]._serialized_options = b'\202\326\033\017\n\rWriteOverload'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD_SHARD"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD_SHARD"]._serialized_options = b'\202\326\033\024\n\022WriteOverloadShard'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_TIME"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_TIME"]._serialized_options = b'\202\326\033\016\n\014IndexingTime'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_TIME"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_TIME"]._serialized_options = b'\202\326\033\020\n\016CompactionTime'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\274\001\022\007\010\220N\022\00210\022\010\010\240\234\001\022\00220\022\010\010\320\206\003\022\00250\022\t\010\240\215\006\022\003100\022\t\010\300\232\014\022\003200\022\t\010\240\302\036\022\003500\022\n\010\300\204=\022\0041000\022\n\010\200\211z\022\0042000\022\013\010\300\226\261\002\022\0045000\022\014\010\200\255\342\004\022\00510000\022\014\010\200\332\304\t\022\00520000\022\014\010\200\216\316\034\022\00560000\022\r\010\200\234\2349\022\006120000\022\016\010\200\306\206\217\001\022\006300000\022\016\010\200\214\215\236\002\022\006600000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SCAN_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SCAN_LATENCY"]._serialized_options = b'\202\326\033\r\n\013ScanLatency'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SCHEMA"]._serialized_options = b'\212\326\033\020\n\016TxUpdateSchema'
  _ETXTYPES.values_by_name["TXTYPE_WRITE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_WRITE"]._serialized_options = b'\212\326\033\t\n\007TxWrite'
  _ETXTYPES.values_by_name["TXTYPE_READ"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_READ"]._serialized_options = b'\212\326\033\010\n\006TxRead'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._serialized_options = b'\212\326\033\013\n\tTxPropose'
  _ETXTYPES.values_by_name["TXTYPE_WRITE_INDEX"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_WRITE_INDEX"]._serialized_options = b'\212\326\033\016\n\014TxWriteIndex'
  _ETXTYPES.values_by_name["TXTYPE_PLANSTEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PLANSTEP"]._serialized_options = b'\212\326\033\014\n\nTxPlanStep'
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_TX_COMPLETION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_TX_COMPLETION"]._serialized_options = b'\212\326\033\026\n\024TxNotifyTxCompletion'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_CANCEL"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_CANCEL"]._serialized_options = b'\212\326\033\021\n\017TxProposeCancel'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS"]._serialized_options = b'\212\326\033\014\n\nTxProgress'
  _ETXTYPES.values_by_name["TXTYPE_START_SCAN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_START_SCAN"]._serialized_options = b'\212\326\033\r\n\013TxStartScan'
  _ETXTYPES.values_by_name["TXTYPE_READ_BLOB_RANGES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_READ_BLOB_RANGES"]._serialized_options = b'\212\326\033\022\n\020TxReadBlobRanges'
  _ETXTYPES.values_by_name["TXTYPE_EXPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_EXPORT"]._serialized_options = b'\212\326\033\n\n\010TxExport'
  _ETXTYPES.values_by_name["TXTYPE_FORGET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FORGET"]._serialized_options = b'\212\326\033\n\n\010TxForget'
  _ESIMPLECOUNTERS._serialized_start=101
  _ESIMPLECOUNTERS._serialized_end=2475
  _ECUMULATIVECOUNTERS._serialized_start=2478
  _ECUMULATIVECOUNTERS._serialized_end=6707
  _EPERCENTILECOUNTERS._serialized_start=6710
  _EPERCENTILECOUNTERS._serialized_end=6972
  _ETXTYPES._serialized_start=6975
  _ETXTYPES._serialized_end=7607
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/fq_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.yq.libs.config.protos import audit_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_audit__pb2
from ydb.core.yq.libs.config.protos import checkpoint_coordinator_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_checkpoint__coordinator__pb2
from ydb.core.yq.libs.config.protos import common_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_common__pb2
from ydb.core.yq.libs.config.protos import control_plane_proxy_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_control__plane__proxy__pb2
from ydb.core.yq.libs.config.protos import control_plane_storage_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_control__plane__storage__pb2
from ydb.core.yq.libs.config.protos import db_pool_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_db__pool__pb2
from ydb.core.yq.libs.config.protos import gateways_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_gateways__pb2
from ydb.core.yq.libs.config.protos import health_config_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_health__config__pb2
from ydb.core.yq.libs.config.protos import nodes_manager_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_nodes__manager__pb2
from ydb.core.yq.libs.config.protos import pending_fetcher_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_pending__fetcher__pb2
from ydb.core.yq.libs.config.protos import pinger_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_pinger__pb2
from ydb.core.yq.libs.config.protos import private_api_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_private__api__pb2
from ydb.core.yq.libs.config.protos import private_proxy_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_private__proxy__pb2
from ydb.core.yq.libs.config.protos import quotas_manager_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_quotas__manager__pb2
from ydb.core.yq.libs.config.protos import rate_limiter_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_rate__limiter__pb2
from ydb.core.yq.libs.config.protos import read_actors_factory_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_read__actors__factory__pb2
from ydb.core.yq.libs.config.protos import resource_manager_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_resource__manager__pb2
from ydb.core.yq.libs.config.protos import test_connection_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_test__connection__pb2
from ydb.core.yq.libs.config.protos import token_accessor_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_token__accessor__pb2
from ydb.library.folder_service.proto import config_pb2 as ydb_dot_library_dot_folder__service_dot_proto_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/core/yq/libs/config/protos/fq_config.proto\x12\x0bNYq.NConfig\x1a*ydb/core/yq/libs/config/protos/audit.proto\x1a;ydb/core/yq/libs/config/protos/checkpoint_coordinator.proto\x1a+ydb/core/yq/libs/config/protos/common.proto\x1a\x38ydb/core/yq/libs/config/protos/control_plane_proxy.proto\x1a:ydb/core/yq/libs/config/protos/control_plane_storage.proto\x1a,ydb/core/yq/libs/config/protos/db_pool.proto\x1a-ydb/core/yq/libs/config/protos/gateways.proto\x1a\x32ydb/core/yq/libs/config/protos/health_config.proto\x1a\x32ydb/core/yq/libs/config/protos/nodes_manager.proto\x1a\x34ydb/core/yq/libs/config/protos/pending_fetcher.proto\x1a+ydb/core/yq/libs/config/protos/pinger.proto\x1a\x30ydb/core/yq/libs/config/protos/private_api.proto\x1a\x32ydb/core/yq/libs/config/protos/private_proxy.proto\x1a\x33ydb/core/yq/libs/config/protos/quotas_manager.proto\x1a\x31ydb/core/yq/libs/config/protos/rate_limiter.proto\x1a\x38ydb/core/yq/libs/config/protos/read_actors_factory.proto\x1a\x35ydb/core/yq/libs/config/protos/resource_manager.proto\x1a\x34ydb/core/yq/libs/config/protos/test_connection.proto\x1a\x33ydb/core/yq/libs/config/protos/token_accessor.proto\x1a-ydb/library/folder_service/proto/config.proto\"\xca\t\n\x07TConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12*\n\x06\x43ommon\x18\x02 \x01(\x0b\x32\x1a.NYq.NConfig.TCommonConfig\x12\x44\n\x13\x43ontrolPlaneStorage\x18\x03 \x01(\x0b\x32\'.NYq.NConfig.TControlPlaneStorageConfig\x12@\n\x11\x43ontrolPlaneProxy\x18\x04 \x01(\x0b\x32%.NYq.NConfig.TControlPlaneProxyConfig\x12H\n\rFolderService\x18\x05 \x01(\x0b\x32\x31.NKikimrProto.NFolderService.TFolderServiceConfig\x12\x32\n\nPrivateApi\x18\x06 \x01(\x0b\x32\x1e.NYq.NConfig.TPrivateApiConfig\x12\x38\n\rTokenAccessor\x18\x07 \x01(\x0b\x32!.NYq.NConfig.TTokenAccessorConfig\x12*\n\x06\x44\x62Pool\x18\x08 \x01(\x0b\x32\x1a.NYq.NConfig.TDbPoolConfig\x12.\n\x08Gateways\x18\t \x01(\x0b\x32\x1c.NYq.NConfig.TGatewaysConfig\x12H\n\x15\x43heckpointCoordinator\x18\n \x01(\x0b\x32).NYq.NConfig.TCheckpointCoordinatorConfig\x12(\n\x05\x41udit\x18\x0b \x01(\x0b\x32\x19.NYq.NConfig.TAuditConfig\x12<\n\x0fResourceManager\x18\x0c \x01(\x0b\x32#.NYq.NConfig.TResourceManagerConfig\x12\x36\n\x0cPrivateProxy\x18\r \x01(\x0b\x32 .NYq.NConfig.TPrivateProxyConfig\x12\x36\n\x0cNodesManager\x18\x0e \x01(\x0b\x32 .NYq.NConfig.TNodesManagerConfig\x12:\n\x0ePendingFetcher\x18\x0f \x01(\x0b\x32\".NYq.NConfig.TPendingFetcherConfig\x12*\n\x06Pinger\x18\x10 \x01(\x0b\x32\x1a.NYq.NConfig.TPingerConfig\x12 \n\x18\x45nableDynamicNameservice\x18\x11 \x01(\x08\x12:\n\x0eTestConnection\x18\x12 \x01(\x0b\x32\".NYq.NConfig.TTestConnectionConfig\x12\x46\n\x17ReadActorsFactoryConfig\x18\x13 \x01(\x0b\x32%.NYq.NConfig.TReadActorsFactoryConfig\x12*\n\x06Health\x18\x14 \x01(\x0b\x32\x1a.NYq.NConfig.THealthConfig\x12\x38\n\rQuotasManager\x18\x15 \x01(\x0b\x32!.NYq.NConfig.TQuotasManagerConfig\x12\x34\n\x0bRateLimiter\x18\x16 \x01(\x0b\x32\x1f.NYq.NConfig.TRateLimiterConfig\x12\x1a\n\x12\x45nableTaskCounters\x18\x17 \x01(\x08\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.fq_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TCONFIG._serialized_start=1101
  _TCONFIG._serialized_end=2327
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/ssa.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/ssa.proto\x12\nNKikimrSSA\"\xf0\x12\n\x08TProgram\x12.\n\x07\x43ommand\x18\x01 \x03(\x0b\x32\x1d.NKikimrSSA.TProgram.TCommand\x12\x0f\n\x07Version\x18\x02 \x01(\r\x1a#\n\x07TColumn\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\x1a\xae\x01\n\tTConstant\x12\x0e\n\x04\x42ool\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05Int32\x18\x02 \x01(\x05H\x00\x12\x10\n\x06Uint32\x18\x03 \x01(\rH\x00\x12\x0f\n\x05Int64\x18\x04 \x01(\x03H\x00\x12\x10\n\x06Uint64\x18\x05 \x01(\x04H\x00\x12\x0f\n\x05\x46loat\x18\x06 \x01(\x02H\x00\x12\x10\n\x06\x44ouble\x18\x07 \x01(\x01H\x00\x12\x0f\n\x05\x42ytes\x18\x08 \x01(\x0cH\x00\x12\x0e\n\x04Text\x18\t \x01(\tH\x00\x42\x07\n\x05value\x1a\x1a\n\nTParameter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x1a\xec\t\n\x0bTAssignment\x12,\n\x06\x43olumn\x18\x01 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x12>\n\x08\x46unction\x18\x02 \x01(\x0b\x32*.NKikimrSSA.TProgram.TAssignment.TFunctionH\x00\x12N\n\x10\x45xternalFunction\x18\x03 \x01(\x0b\x32\x32.NKikimrSSA.TProgram.TAssignment.TExternalFunctionH\x00\x12\x32\n\x08\x43onstant\x18\x04 \x01(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstantH\x00\x12\x0e\n\x04Null\x18\x05 \x01(\x08H\x00\x12\x34\n\tParameter\x18\x06 \x01(\x0b\x32\x1f.NKikimrSSA.TProgram.TParameterH\x00\x1aH\n\tTFunction\x12\n\n\x02Id\x18\x01 \x01(\r\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1aR\n\x11TExternalFunction\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\"\xf8\x05\n\tEFunction\x12\x14\n\x10\x46UNC_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46UNC_CMP_EQUAL\x10\x01\x12\x16\n\x12\x46UNC_CMP_NOT_EQUAL\x10\x02\x12\x11\n\rFUNC_CMP_LESS\x10\x03\x12\x17\n\x13\x46UNC_CMP_LESS_EQUAL\x10\x04\x12\x14\n\x10\x46UNC_CMP_GREATER\x10\x05\x12\x1a\n\x16\x46UNC_CMP_GREATER_EQUAL\x10\x06\x12\x10\n\x0c\x46UNC_IS_NULL\x10\x07\x12\x13\n\x0f\x46UNC_STR_LENGTH\x10\x08\x12\x12\n\x0e\x46UNC_STR_MATCH\x10\t\x12\x13\n\x0f\x46UNC_BINARY_NOT\x10\n\x12\x13\n\x0f\x46UNC_BINARY_AND\x10\x0b\x12\x12\n\x0e\x46UNC_BINARY_OR\x10\x0c\x12\x13\n\x0f\x46UNC_BINARY_XOR\x10\r\x12\x11\n\rFUNC_MATH_ADD\x10\x0e\x12\x16\n\x12\x46UNC_MATH_SUBTRACT\x10\x0f\x12\x16\n\x12\x46UNC_MATH_MULTIPLY\x10\x10\x12\x14\n\x10\x46UNC_MATH_DIVIDE\x10\x11\x12\x18\n\x14\x46UNC_CAST_TO_BOOLEAN\x10\x12\x12\x15\n\x11\x46UNC_CAST_TO_INT8\x10\x13\x12\x16\n\x12\x46UNC_CAST_TO_INT16\x10\x14\x12\x16\n\x12\x46UNC_CAST_TO_INT32\x10\x15\x12\x16\n\x12\x46UNC_CAST_TO_INT64\x10\x16\x12\x16\n\x12\x46UNC_CAST_TO_UINT8\x10\x17\x12\x17\n\x13\x46UNC_CAST_TO_UINT16\x10\x18\x12\x17\n\x13\x46UNC_CAST_TO_UINT32\x10\x19\x12\x17\n\x13\x46UNC_CAST_TO_UINT64\x10\x1a\x12\x16\n\x12\x46UNC_CAST_TO_FLOAT\x10\x1b\x12\x17\n\x13\x46UNC_CAST_TO_DOUBLE\x10\x1c\x12\x17\n\x13\x46UNC_CAST_TO_BINARY\x10\x1d\x12\"\n\x1e\x46UNC_CAST_TO_FIXED_SIZE_BINARY\x10\x1e\x12\x1a\n\x16\x46UNC_CAST_TO_TIMESTAMP\x10\x1f\x42\x0c\n\nexpression\x1a\xe7\x02\n\x14TAggregateAssignment\x12,\n\x06\x43olumn\x18\x01 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x12N\n\x08\x46unction\x18\x02 \x01(\x0b\x32<.NKikimrSSA.TProgram.TAggregateAssignment.TAggregateFunction\x1a\x62\n\x12TAggregateFunction\x12\n\n\x02Id\x18\x01 \x01(\r\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x12\x0f\n\x07Variant\x18\x03 \x01(\t\"m\n\x12\x45\x41ggregateFunction\x12\x13\n\x0f\x41GG_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x41GG_SOME\x10\x01\x12\r\n\tAGG_COUNT\x10\x02\x12\x0b\n\x07\x41GG_MIN\x10\x03\x12\x0b\n\x07\x41GG_MAX\x10\x04\x12\x0b\n\x07\x41GG_SUM\x10\x05\x1a<\n\x0bTProjection\x12-\n\x07\x43olumns\x18\x01 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1a:\n\x07TFilter\x12/\n\tPredicate\x18\x01 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1a{\n\x08TGroupBy\x12=\n\nAggregates\x18\x01 \x03(\x0b\x32).NKikimrSSA.TProgram.TAggregateAssignment\x12\x30\n\nKeyColumns\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1a\xe0\x01\n\x08TCommand\x12\x32\n\x06\x41ssign\x18\x01 \x01(\x0b\x32 .NKikimrSSA.TProgram.TAssignmentH\x00\x12\x36\n\nProjection\x18\x02 \x01(\x0b\x32 .NKikimrSSA.TProgram.TProjectionH\x00\x12.\n\x06\x46ilter\x18\x03 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TFilterH\x00\x12\x30\n\x07GroupBy\x18\x04 \x01(\x0b\x32\x1d.NKikimrSSA.TProgram.TGroupByH\x00\x42\x06\n\x04line\"M\n\x0cTOlapProgram\x12\x0f\n\x07Program\x18\x01 \x01(\x0c\x12\x18\n\x10ParametersSchema\x18\x02 \x01(\x0c\x12\x12\n\nParameters\x18\x03 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.ssa_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPROGRAM._serialized_start=42
  _TPROGRAM._serialized_end=2458
  _TPROGRAM_TCOLUMN._serialized_start=119
  _TPROGRAM_TCOLUMN._serialized_end=154
  _TPROGRAM_TCONSTANT._serialized_start=157
  _TPROGRAM_TCONSTANT._serialized_end=331
  _TPROGRAM_TPARAMETER._serialized_start=333
  _TPROGRAM_TPARAMETER._serialized_end=359
  _TPROGRAM_TASSIGNMENT._serialized_start=362
  _TPROGRAM_TASSIGNMENT._serialized_end=1622
  _TPROGRAM_TASSIGNMENT_TFUNCTION._serialized_start=689
  _TPROGRAM_TASSIGNMENT_TFUNCTION._serialized_end=761
  _TPROGRAM_TASSIGNMENT_TEXTERNALFUNCTION._serialized_start=763
  _TPROGRAM_TASSIGNMENT_TEXTERNALFUNCTION._serialized_end=845
  _TPROGRAM_TASSIGNMENT_EFUNCTION._serialized_start=848
  _TPROGRAM_TASSIGNMENT_EFUNCTION._serialized_end=1608
  _TPROGRAM_TAGGREGATEASSIGNMENT._serialized_start=1625
  _TPROGRAM_TAGGREGATEASSIGNMENT._serialized_end=1984
  _TPROGRAM_TAGGREGATEASSIGNMENT_TAGGREGATEFUNCTION._serialized_start=1775
  _TPROGRAM_TAGGREGATEASSIGNMENT_TAGGREGATEFUNCTION._serialized_end=1873
  _TPROGRAM_TAGGREGATEASSIGNMENT_EAGGREGATEFUNCTION._serialized_start=1875
  _TPROGRAM_TAGGREGATEASSIGNMENT_EAGGREGATEFUNCTION._serialized_end=1984
  _TPROGRAM_TPROJECTION._serialized_start=1986
  _TPROGRAM_TPROJECTION._serialized_end=2046
  _TPROGRAM_TFILTER._serialized_start=2048
  _TPROGRAM_TFILTER._serialized_end=2106
  _TPROGRAM_TGROUPBY._serialized_start=2108
  _TPROGRAM_TGROUPBY._serialized_end=2231
  _TPROGRAM_TCOMMAND._serialized_start=2234
  _TPROGRAM_TCOMMAND._serialized_end=2458
  _TOLAPPROGRAM._serialized_start=2460
  _TOLAPPROGRAM._serialized_end=2537
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/bootstrapper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/bootstrapper.proto\x12\x13NKikimrBootstrapper\"=\n\x08TEvWatch\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x10\n\x08SelfSeed\x18\x02 \x01(\x04\x12\r\n\x05Round\x18\x03 \x01(\x04\"\xd6\x01\n\x0eTEvWatchResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x39\n\x05State\x18\x02 \x01(\x0e\x32*.NKikimrBootstrapper.TEvWatchResult.EState\x12\x0c\n\x04Seed\x18\x03 \x01(\x04\x12\r\n\x05Round\x18\x04 \x01(\x04\"Z\n\x06\x45State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\t\n\x05OWNER\x10\x02\x12\x0b\n\x07WAITFOR\x10\x03\x12\x0f\n\x0bUNDELIVERED\x10\x04\x12\x10\n\x0c\x44ISCONNECTED\x10\x05\"z\n\tTEvNotify\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12.\n\x02Op\x18\x02 \x01(\x0e\x32\".NKikimrBootstrapper.TEvNotify.EOp\x12\r\n\x05Round\x18\x03 \x01(\x04\"\x1c\n\x03\x45Op\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x44ROP\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.bootstrapper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVWATCH._serialized_start=59
  _TEVWATCH._serialized_end=120
  _TEVWATCHRESULT._serialized_start=123
  _TEVWATCHRESULT._serialized_end=337
  _TEVWATCHRESULT_ESTATE._serialized_start=247
  _TEVWATCHRESULT_ESTATE._serialized_end=337
  _TEVNOTIFY._serialized_start=339
  _TEVNOTIFY._serialized_end=461
  _TEVNOTIFY_EOP._serialized_start=433
  _TEVNOTIFY_EOP._serialized_end=461
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_type_operation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/core/protos/scheme_type_operation.proto\x12\x1aNKikimrSchemeTypeOperation\"\xc0\x02\n\tTMetadata\x12\x43\n\tOperation\x18\x01 \x03(\x0b\x32\x30.NKikimrSchemeTypeOperation.TMetadata.TOperation\x1a)\n\x04TArg\x12\x12\n\nSchemeType\x18\x01 \x01(\r\x12\r\n\x05\x46lags\x18\x02 \x01(\r\x1a^\n\x0cTDescription\x12\x37\n\x03\x41rg\x18\x01 \x03(\x0b\x32*.NKikimrSchemeTypeOperation.TMetadata.TArg\x12\x15\n\rDeterministic\x18\x02 \x01(\x08\x1a\x63\n\nTOperation\x12\x0c\n\x04Name\x18\x01 \x01(\x0c\x12G\n\x0b\x44\x65scription\x18\x02 \x03(\x0b\x32\x32.NKikimrSchemeTypeOperation.TMetadata.TDescriptionB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_type_operation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TMETADATA._serialized_start=76
  _TMETADATA._serialized_end=396
  _TMETADATA_TARG._serialized_start=158
  _TMETADATA_TARG._serialized_end=199
  _TMETADATA_TDESCRIPTION._serialized_start=201
  _TMETADATA_TDESCRIPTION._serialized_end=295
  _TMETADATA_TOPERATION._serialized_start=297
  _TMETADATA_TOPERATION._serialized_end=396
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_tx_allocator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/core/protos/counters_tx_allocator.proto\x12\x14NKikimr.NTxAllocator\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*N\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12#\n\x0eTXTYPE_RESERVE\x10\x01\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxReserveB\'\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0bTxAllocator')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_tx_allocator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\013TxAllocator'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_RESERVE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESERVE"]._serialized_options = b'\212\326\033\013\n\tTxReserve'
  _ESIMPLECOUNTERS._serialized_start=101
  _ESIMPLECOUNTERS._serialized_end=145
  _ECUMULATIVECOUNTERS._serialized_start=147
  _ECUMULATIVECOUNTERS._serialized_end=199
  _EPERCENTILECOUNTERS._serialized_start=201
  _EPERCENTILECOUNTERS._serialized_end=279
  _ETXTYPES._serialized_start=281
  _ETXTYPES._serialized_end=359
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: library/cpp/actors/protos/services_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/library/cpp/actors/protos/services_common.proto\x12\x0fNActorsServices*\xbb\x01\n\x0e\x45ServiceCommon\x12\n\n\x06GLOBAL\x10\x00\x12\x10\n\x0cINTERCONNECT\x10\x01\x12\x08\n\x04TEST\x10\x02\x12\r\n\tPROTOCOLS\x10\x03\x12\x1b\n\x17INTERCONNECT_SPEED_TEST\x10\x04\x12\x17\n\x13INTERCONNECT_STATUS\x10\x05\x12\x18\n\x14INTERCONNECT_NETWORK\x10\x06\x12\x18\n\x14INTERCONNECT_SESSION\x10\x07\x12\x08\n\x04HTTP\x10\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'library.cpp.actors.protos.services_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESERVICECOMMON._serialized_start=69
  _ESERVICECOMMON._serialized_end=256
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/stream.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/stream.proto\x12\rNKikimrStream\"\xad\x03\n\x10TStreamingConfig\x12 \n\x12\x45nableInputStreams\x18\x01 \x01(\x08:\x04true\x12!\n\x13\x45nableOutputStreams\x18\x02 \x01(\x08:\x04true\x12O\n\x12OutputStreamConfig\x18\x03 \x01(\x0b\x32\x33.NKikimrStream.TStreamingConfig.TOutputStreamConfig\x1a\x82\x02\n\x13TOutputStreamConfig\x12\"\n\x10MessageSizeLimit\x18\x01 \x01(\x04:\x08\x32\x30\x39\x37\x31\x35\x32\x30\x12$\n\x11MessageBufferSize\x18\x02 \x01(\x04:\t536870912\x12\x17\n\x0cMinQuotaSize\x18\x03 \x01(\r:\x01\x31\x12\x17\n\x0cMaxQuotaSize\x18\x04 \x01(\r:\x01\x35\x12\x1d\n\x12MaxStreamingShards\x18\x05 \x01(\r:\x01\x35\x12\'\n\x15InactiveClientTimeout\x18\x06 \x01(\x04:\x08\x36\x30\x30\x30\x30\x30\x30\x30\x12\'\n\x15InactiveServerTimeout\x18\x07 \x01(\x04:\x08\x36\x30\x30\x30\x30\x30\x30\x30\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.stream_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSTREAMINGCONFIG._serialized_start=48
  _TSTREAMINGCONFIG._serialized_end=477
  _TSTREAMINGCONFIG_TOUTPUTSTREAMCONFIG._serialized_start=219
  _TSTREAMINGCONFIG_TOUTPUTSTREAMCONFIG._serialized_end=477
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blockstore_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/core/protos/blockstore_config.proto\x12\x11NKikimrBlockStore\"\x97\x01\n\x0fTChannelProfile\x12\x10\n\x08PoolKind\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\x04\x12\x10\n\x08ReadIops\x18\x03 \x01(\x01\x12\x15\n\rReadBandwidth\x18\x04 \x01(\x01\x12\x11\n\tWriteIops\x18\x05 \x01(\x01\x12\x16\n\x0eWriteBandwidth\x18\x06 \x01(\x01\x12\x10\n\x08\x44\x61taKind\x18\x65 \x01(\r\"0\n\x0fTEncryptionDesc\x12\x0c\n\x04Mode\x18\x01 \x01(\r\x12\x0f\n\x07KeyHash\x18\x02 \x01(\x0c\"\xf7\n\n\rTVolumeConfig\x12\x11\n\tBlockSize\x18\x01 \x01(\r\x12\x12\n\nStripeSize\x18\x02 \x01(\r\x12?\n\nPartitions\x18\x03 \x03(\x0b\x32+.NKikimrBlockStore.TVolumeConfig.TPartition\x12\x13\n\x0bNumChannels\x18\x04 \x01(\r\x12\x18\n\x10\x43hannelProfileId\x18\x05 \x01(\r\x12\x0f\n\x07Version\x18\x06 \x01(\r\x12\x0e\n\x06\x44iskId\x18\x07 \x01(\t\x12\x11\n\tProjectId\x18\x08 \x01(\t\x12\x10\n\x08\x46olderId\x18\t \x01(\t\x12\x0f\n\x07\x43loudId\x18\n \x01(\t\x12\x15\n\rTabletVersion\x18\x0b \x01(\r\x12\x0e\n\x06Opaque\x18\x0c \x01(\x0c\x12\x18\n\x10StorageMediaKind\x18\r \x01(\r\x12*\n\"PerformanceProfileMaxReadBandwidth\x18\x0e \x01(\r\x12,\n$PerformanceProfileMaxPostponedWeight\x18\x10 \x01(\r\x12+\n#PerformanceProfileThrottlingEnabled\x18\x11 \x01(\x08\x12%\n\x1dPerformanceProfileMaxReadIops\x18\x12 \x01(\r\x12#\n\x1bPerformanceProfileBoostTime\x18\x14 \x01(\r\x12)\n!PerformanceProfileBoostRefillTime\x18\x15 \x01(\r\x12)\n!PerformanceProfileBoostPercentage\x18\x16 \x01(\r\x12+\n#PerformanceProfileMaxWriteBandwidth\x18\x17 \x01(\r\x12&\n\x1ePerformanceProfileMaxWriteIops\x18\x18 \x01(\r\x12)\n!PerformanceProfileBurstPercentage\x18\x19 \x01(\r\x12\x12\n\nBaseDiskId\x18\x1a \x01(\t\x12\x1c\n\x14\x42\x61seDiskCheckpointId\x18\x1b \x01(\t\x12\x1b\n\x13SizeDecreaseAllowed\x18\x1c \x01(\x08\x12\x43\n\x17\x45xplicitChannelProfiles\x18\x1d \x03(\x0b\x32\".NKikimrBlockStore.TChannelProfile\x12\x1d\n\x15PoolKindChangeAllowed\x18\x1e \x01(\x08\x12\x17\n\x0fMaxBlocksInBlob\x18\x1f \x01(\r\x12\x12\n\nCreationTs\x18  \x01(\x04\x12\x0f\n\x07\x41lterTs\x18! \x01(\x04\x12\x18\n\x10PlacementGroupId\x18\" \x01(\t\x12\x0f\n\x07TagsStr\x18# \x01(\t\x12\x0c\n\x04Tags\x18$ \x03(\t\x12\x17\n\x0f\x42locksPerStripe\x18% \x01(\r\x12\x16\n\x0eZoneBlockCount\x18& \x01(\r\x12\x10\n\x08IsSystem\x18( \x01(\x08\x12I\n\x1dVolumeExplicitChannelProfiles\x18) \x03(\x0b\x32\".NKikimrBlockStore.TChannelProfile\x12\x17\n\x0fStoragePoolName\x18* \x01(\t\x12\x10\n\x08\x41gentIds\x18+ \x03(\t\x12:\n\x0e\x45ncryptionDesc\x18, \x01(\x0b\x32\".NKikimrBlockStore.TEncryptionDesc\x12\x1c\n\x14PlacementPartitionId\x18- \x01(\t\x1aQ\n\nTPartition\x12\x12\n\nBlockCount\x18\x02 \x01(\x04\x12/\n\x04Type\x18\x03 \x01(\x0e\x32!.NKikimrBlockStore.EPartitionType\"\xd7\x01\n\x13TUpdateVolumeConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x0cVolumeConfig\x18\x02 \x01(\x0b\x32 .NKikimrBlockStore.TVolumeConfig\x12\x45\n\nPartitions\x18\x03 \x03(\x0b\x32\x31.NKikimrBlockStore.TUpdateVolumeConfig.TPartition\x1a\x33\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"g\n\x1bTUpdateVolumeConfigResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12*\n\x06Status\x18\x03 \x01(\x0e\x32\x1a.NKikimrBlockStore.EStatus*0\n\x0e\x45PartitionType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x11\n\rNonReplicated\x10\x01*Q\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x15\n\x11\x45RROR_BAD_VERSION\x10\x02\x12\x1c\n\x18\x45RROR_UPDATE_IN_PROGRESS\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blockstore_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EPARTITIONTYPE._serialized_start=1991
  _EPARTITIONTYPE._serialized_end=2039
  _ESTATUS._serialized_start=2041
  _ESTATUS._serialized_end=2122
  _TCHANNELPROFILE._serialized_start=63
  _TCHANNELPROFILE._serialized_end=214
  _TENCRYPTIONDESC._serialized_start=216
  _TENCRYPTIONDESC._serialized_end=264
  _TVOLUMECONFIG._serialized_start=267
  _TVOLUMECONFIG._serialized_end=1666
  _TVOLUMECONFIG_TPARTITION._serialized_start=1585
  _TVOLUMECONFIG_TPARTITION._serialized_end=1666
  _TUPDATEVOLUMECONFIG._serialized_start=1669
  _TUPDATEVOLUMECONFIG._serialized_end=1884
  _TUPDATEVOLUMECONFIG_TPARTITION._serialized_start=1833
  _TUPDATEVOLUMECONFIG_TPARTITION._serialized_end=1884
  _TUPDATEVOLUMECONFIGRESPONSE._serialized_start=1886
  _TUPDATEVOLUMECONFIGRESPONSE._serialized_end=1989
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/ydb_table_impl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/ydb_table_impl.proto\x12\x08Ydb.Impl\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"\xc1\x01\n\x11ReadTableResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12-\n\x08snapshot\x18\x04 \x01(\x0b\x32\x1b.Ydb.Impl.ReadTableSnapshot\x12)\n\x06result\x18\x03 \x01(\x0b\x32\x19.Ydb.Impl.ReadTableResult\"5\n\x11ReadTableSnapshot\x12\x11\n\tplan_step\x18\x01 \x01(\x04\x12\r\n\x05tx_id\x18\x02 \x01(\x04\"%\n\x0fReadTableResult\x12\x12\n\nresult_set\x18\x01 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.ydb_table_impl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _READTABLERESPONSE._serialized_start=144
  _READTABLERESPONSE._serialized_end=337
  _READTABLESNAPSHOT._serialized_start=339
  _READTABLESNAPSHOT._serialized_end=392
  _READTABLERESULT._serialized_start=394
  _READTABLERESULT._serialized_end=431
# @@protoc_insertion_point(module_scope)



import ydb.apps.dstool.lib.common as common
from ydb.apps.dstool.lib.common import kikimr_bsconfig
from operator import itemgetter, attrgetter
from collections import OrderedDict
import ydb.core.protos.blobstorage_pb2 as kikimr_bs


class IdBase(object):
    def __init__(self):
        super().__init__()

    def __eq__(self, other):
        if not isinstance(other, type(self)):
            return NotImplemented
        return self._data() == other._data()

    def __hash__(self):
        return hash(self._data())


class NodeId(IdBase):
    def __init__(self, value):
        super().__init__()
        assert isinstance(value, int)
        self.value = value

    def _data(self):
        return self.value

    def __str__(self):
        return '%d' % self.value

    def __repr__(self):
        return str(self)


class PDiskId(IdBase):
    def __init__(self, node_id, value):
        super().__init__()
        assert isinstance(node_id, NodeId)
        assert isinstance(value, int)
        self.node_id, self.value = node_id, value

    def _data(self):
        return self.node_id, self.value

    def __str__(self):
        return '%d:%d' % (self.node_id.value, self.value)

    def __repr__(self):
        return str(self)


class VSlotId(IdBase):
    def __init__(self, pdisk_id, value):
        super().__init__()
        assert isinstance(pdisk_id, PDiskId)
        assert isinstance(value, int)
        self.pdisk_id, self.value = pdisk_id, value

    @staticmethod
    def from_proto(vslot_id):
        return VSlotId(PDiskId(NodeId(vslot_id.NodeId), vslot_id.PDiskId), vslot_id.VSlotId)

    def _data(self):
        return self.pdisk_id, self.value

    def __str__(self):
        return '%d:%d:%d' % (self.pdisk_id.node_id.value, self.pdisk_id.value, self.value)

    def __repr__(self):
        return str(self)


class GroupId(IdBase):
    def __init__(self, group_id):
        super().__init__()
        assert isinstance(group_id, int)
        self.value = group_id

    def _data(self):
        return self.value

    def __str__(self):
        return '%d' % self.value

    def __repr__(self):
        return str(self)


class StoragePoolId(IdBase):
    def __init__(self, box_id, storage_pool_id):
        super().__init__()
        assert isinstance(box_id, int)
        assert isinstance(storage_pool_id, int)
        self.box_id, self.storage_pool_id = box_id, storage_pool_id

    def _data(self):
        return self.box_id, self.storage_pool_id

    def __str__(self):
        return '%d.%d' % (self.box_id, self.storage_pool_id)

    def __repr__(self):
        return str(self)


class EntityBase(object):
    def __init__(self):
        super().__init__()

    def __str__(self):
        return '{%s}' % ' '.join(
            '%s# %s' % (k, v)
            for k, v in self._params().items()
            if not isinstance(v, str) or v != ''
        )

    def __repr__(self):
        return str(self)


class Node(EntityBase):
    def __init__(self, base, node_mon_endpoint=None):
        super().__init__()
        self.base = base
        self.node_mon_endpoint = node_mon_endpoint
        self.pdisks_of_node = set()  # a set of references to PDisk structure

    def _params(self):
        return OrderedDict(
            NodeId=NodeId(self.base.NodeId),
            Mon=self.node_mon_endpoint or '',
        )


class PDisk(EntityBase):
    def __init__(self, base, node):
        super().__init__()
        self.base, self.node = base, node
        self.vslots_of_pdisk = set()
        node.pdisks_of_node.add(self)
        self.mon_state = None

    def _params(self):
        return OrderedDict(
            PDiskId=PDiskId(NodeId(self.base.NodeId), self.base.PDiskId),
            Path=self.base.Path,
            MonState=self.mon_state or '',
        )


class VSlot(EntityBase):
    def __init__(self, base, pdisk):
        super().__init__()
        self.base, self.pdisk = base, pdisk
        self.group = None  # a group this VSlot belongs to, if not donor; otherwise None
        self.donors = set()
        self.acceptor = None  # None for an active disk and VSlot reference for donor one
        pdisk.vslots_of_pdisk.add(self)
        self.status = kikimr_bs.EVDiskStatus.Value(self.base.Status) if self.base.Status else None
        self.mon_fetched = False
        self.mon_state = None
        self.mon_replicated = None

    def _params(self):
        return OrderedDict(
            VSlotId=VSlotId.from_proto(self.base.VSlotId),
            VDiskId='[%08x:%d:%d:%d:%d]' % (self.base.GroupId, self.base.GroupGeneration, self.base.FailRealmIdx, self.base.FailDomainIdx, self.base.VDiskIdx),
            Kind=self.base.VDiskKind,
            Status=self.base.Status,
            DonorCount='itself' if self.acceptor else str(len(self.donors)),
        )


class Group(EntityBase):
    def __init__(self, base, layout):
        super().__init__()
        self.base = base
        self.storage_pool = None
        self.vslots_of_group = [
            layout.vslots[vslot_id]
            for vslot_id in map(VSlotId.from_proto, self.base.VSlotId)
        ]
        for vslot in self.vslots_of_group:
            vslot.group = self

    def _params(self):
        return OrderedDict(
            GroupId='%d:%d' % (self.base.GroupId, self.base.GroupGeneration),
            Erasure=self.base.ErasureSpecies,
            VSlots='[%s]' % ' '.join(str(VSlotId.from_proto(id_)) for id_ in self.base.VSlotId),
            StoragePoolId=StoragePoolId(self.base.BoxId, self.base.StoragePoolId),
            Name=self.storage_pool.base.Name if self.storage_pool else 'static',
        )


class StoragePool(EntityBase):
    def __init__(self, base):
        super().__init__()
        self.base = base
        self.groups = set()

    def _params(self):
        return OrderedDict(
            StoragePoolId=StoragePoolId(self.base.BoxId, self.base.StoragePoolId),
            Name=self.base.Name,
        )


class BlobStorageLayout(object):
    def __init__(self):
        # fetch essential storage configuration from blb storage controller
        base_config, storage_pools = itemgetter('BaseConfig', 'StoragePools')(common.fetch_base_config_and_storage_pools())

        # build a map of nodes
        self.nodes = {
            NodeId(node.NodeId): Node(node)
            for node in base_config.Node
        }

        # then go the pdisks
        self.pdisks = {
            pdisk_id: PDisk(pdisk, self.nodes[pdisk_id.node_id])
            for pdisk in base_config.PDisk
            for pdisk_id in [PDiskId(NodeId(pdisk.NodeId), pdisk.PDiskId)]
        }

        # then the vslots
        self.vslots = {
            vslot_id: VSlot(vslot, self.pdisks[vslot_id.pdisk_id])
            for vslot in base_config.VSlot
            for vslot_id in [VSlotId.from_proto(vslot.VSlotId)]
        }

        # fix the donors
        donors = {}
        for vslot in self.vslots.values():
            for donor in vslot.base.Donors:
                id_ = VSlotId.from_proto(donor.VSlotId)
                vdisk_id = donor.VDiskId
                donor_vslot = VSlot(
                    kikimr_bsconfig.TBaseConfig.TVSlot(
                        VSlotId=donor.VSlotId,
                        GroupId=vdisk_id.GroupID,
                        GroupGeneration=vdisk_id.GroupGeneration,
                        FailRealmIdx=vdisk_id.Ring,
                        FailDomainIdx=vdisk_id.Domain,
                        VDiskIdx=vdisk_id.VDisk,
                        VDiskMetrics=donor.VDiskMetrics,
                    ),
                    self.pdisks[id_.pdisk_id]
                )
                donor_vslot.acceptor = vslot
                vslot.donors.add(donor_vslot)
                donors[id_] = donor_vslot

        # add donors to self.vslots
        self.vslots.update(donors)

        # the groups
        self.groups = {
            GroupId(group.GroupId): Group(group, self)
            for group in base_config.Group
        }

        # aaand the storage pools
        self.storage_pools = {
            StoragePoolId(sp.BoxId, sp.StoragePoolId): StoragePool(sp)
            for sp in storage_pools
        }

        # fix group mapping
        for group in self.groups.values():
            sp_id = StoragePoolId(group.base.BoxId, group.base.StoragePoolId)
            if sp_id != StoragePoolId(0, 0):
                sp = self.storage_pools[sp_id]
                group.storage_pool = sp
                sp.groups.add(group)

    def fetch_node_mon_endpoints(self, nodes=None):
        """ Fetch monitoring endpoints for specific nodes (if set) or for all of them. """
        if isinstance(nodes, str) and nodes == 'storage':
            nodes = {pdisk_id.node_id for pdisk_id in self.pdisks}

        def get_nodes():
            for node_id in nodes if nodes is not None else self.nodes:
                assert isinstance(node_id, NodeId)
                if self.nodes[node_id].node_mon_endpoint is None:
                    yield node_id.value

        for node_id, sysinfo in common.fetch_json_info('sysinfo', get_nodes()).items():
            node_id = NodeId(node_id)
            node = self.nodes[node_id]
            for ep in sysinfo.get('Endpoints', []):
                if ep['Name'] == 'http-mon':
                    node.node_mon_endpoint = sysinfo['Host'] + ep['Address']

    def fetch_pdisk_mon_state(self, nodes=None):
        possible_nodes = {pdisk_id.node_id for pdisk_id, pdisk in self.pdisks.items() if pdisk.mon_state is None}
        nodes = nodes & possible_nodes if nodes is not None else possible_nodes
        for (node_id, pdisk_id), pdiskinfo in common.fetch_json_info('pdiskinfo', (x.value for x in nodes), enums=0).items():
            pdisk_id = PDiskId(NodeId(node_id), pdisk_id)
            self.pdisks[pdisk_id].mon_state = pdiskinfo.get('State')

    def fetch_vdisk_mon_state(self, nodes=None):
        possible_nodes = {vslot_id.pdisk_id.node_id for vslot_id, vslot in self.vslots.items() if not vslot.mon_fetched}
        nodes = nodes & possible_nodes if nodes is not None else possible_nodes
        json_get = itemgetter('GroupID', 'Ring', 'Domain', 'VDisk')
        proto_get = attrgetter('GroupId', 'FailRealmIdx', 'FailDomainIdx', 'VDiskIdx')
        for (node_id, pdisk_id, vslot_id), vdiskinfo in common.fetch_json_info('vdiskinfo', (x.value for x in nodes), enums=0).items():
            vslot = self.vslots.get(VSlotId(PDiskId(NodeId(node_id), pdisk_id), vslot_id))
            if vslot and json_get(vdiskinfo['VDiskId']) == proto_get(vslot.base):
                vslot.mon_fetched = True
                vslot.mon_state = vdiskinfo.get('VDiskState')
                vslot.mon_replicated = vdiskinfo.get('Replicated')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_board_mon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/scheme_board_mon.proto\x12\x15NKikimrSchemeBoardMon\x1a&library/cpp/actors/protos/actors.proto\"3\n\x0eTEvInfoRequest\x12!\n\x13LimitRepeatedFields\x18\x01 \x01(\r:\x04\x31\x30\x30\x30\"\x91\x05\n\x0fTEvInfoResponse\x12$\n\x04Self\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x14\n\x0c\x41\x63tivityType\x18\x0b \x01(\t\x12\x18\n\tTruncated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x42\n\x0fReplicaResponse\x18\x04 \x01(\x0b\x32\'.NKikimrSchemeBoardMon.TReplicaResponseH\x00\x12\x46\n\x11PopulatorResponse\x18\x05 \x01(\x0b\x32).NKikimrSchemeBoardMon.TPopulatorResponseH\x00\x12T\n\x18ReplicaPopulatorResponse\x18\x06 \x01(\x0b\x32\x30.NKikimrSchemeBoardMon.TReplicaPopulatorResponseH\x00\x12H\n\x12SubscriberResponse\x18\x07 \x01(\x0b\x32*.NKikimrSchemeBoardMon.TSubscriberResponseH\x00\x12R\n\x17SubscriberProxyResponse\x18\x08 \x01(\x0b\x32/.NKikimrSchemeBoardMon.TSubscriberProxyResponseH\x00\x12V\n\x19ReplicaSubscriberResponse\x18\t \x01(\x0b\x32\x31.NKikimrSchemeBoardMon.TReplicaSubscriberResponseH\x00\x12>\n\rCacheResponse\x18\n \x01(\x0b\x32%.NKikimrSchemeBoardMon.TCacheResponseH\x00\x42\n\n\x08ResponseJ\x04\x08\x02\x10\x03\"b\n\x12TEvDescribeRequest\x12\x0e\n\x04Path\x18\x01 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x02 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"#\n\x13TEvDescribeResponse\x12\x0c\n\x04Json\x18\x01 \x01(\t\"/\n\x07TPathId\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x02 \x01(\x04\"\xd6\x04\n\x10TReplicaResponse\x12J\n\nPopulators\x18\x01 \x03(\x0b\x32\x36.NKikimrSchemeBoardMon.TReplicaResponse.TPopulatorInfo\x12O\n\x0c\x44\x65scriptions\x18\x02 \x01(\x0b\x32\x39.NKikimrSchemeBoardMon.TReplicaResponse.TDescriptionsInfo\x12L\n\x0bSubscribers\x18\x03 \x03(\x0b\x32\x37.NKikimrSchemeBoardMon.TReplicaResponse.TSubscriberInfo\x1aw\n\x0eTPopulatorInfo\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x19\n\x11PendingGeneration\x18\x03 \x01(\x04\x12\'\n\x07\x41\x63torId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1aS\n\x11TDescriptionsInfo\x12\x12\n\nTotalCount\x18\x01 \x01(\x04\x12\x13\n\x0b\x42yPathCount\x18\x02 \x01(\x04\x12\x15\n\rByPathIdCount\x18\x03 \x01(\x04\x1a\x88\x01\n\x0fTSubscriberInfo\x12\'\n\x07\x41\x63torId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x04Path\x18\x02 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x03 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"\xaa\x04\n\x12TPopulatorResponse\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x19\n\x11\x44\x65scriptionsCount\x18\x03 \x01(\x04\x12\x31\n\tMaxPathId\x18\x04 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x1b\n\x13\x44\x65layedUpdatesCount\x18\x05 \x01(\x04\x12\x31\n\x11ReplicaPopulators\x18\x06 \x03(\x0b\x32\x16.NActorsProto.TActorId\x12L\n\nUpdateAcks\x18\x07 \x03(\x0b\x32\x38.NKikimrSchemeBoardMon.TPopulatorResponse.TUpdateAckInfo\x1a\x84\x02\n\x0eTUpdateAckInfo\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12%\n\x05\x41\x63kTo\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12W\n\x08PathAcks\x18\x03 \x03(\x0b\x32\x45.NKikimrSchemeBoardMon.TPopulatorResponse.TUpdateAckInfo.TPathAckInfo\x1a\x62\n\x0cTPathAckInfo\x12.\n\x06PathId\x18\x01 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\x11\n\tAcksCount\x18\x03 \x01(\r\"\xf1\x05\n\x19TReplicaPopulatorResponse\x12&\n\x06Parent\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\'\n\x07Replica\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\r\n\x05Owner\x18\x03 \x01(\x04\x12\x12\n\nGeneration\x18\x04 \x01(\x04\x12\x31\n\tCurPathId\x18\x05 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x37\n\x0fLastAckedPathId\x18\x06 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x11\n\tBatchSize\x18\x07 \x01(\r\x12\x16\n\x0e\x42\x61tchSizeLimit\x18\x08 \x01(\r\x12M\n\x07Updates\x18\t \x03(\x0b\x32<.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo\x12V\n\x10UpdatesRequested\x18\n \x03(\x0b\x32<.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo\x12U\n\x0fUpdatesInFlight\x18\x0b \x03(\x0b\x32<.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo\x1a\xca\x01\n\x0bTUpdateInfo\x12.\n\x06PathId\x18\x01 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12[\n\x08Versions\x18\x02 \x03(\x0b\x32I.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo.TVersionInfo\x1a.\n\x0cTVersionInfo\x12\x0f\n\x07Version\x18\x01 \x01(\x04\x12\r\n\x05TxIds\x18\x02 \x03(\x04\"\xb2\x05\n\x13TSubscriberResponse\x12%\n\x05Owner\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x15\n\rDomainOwnerId\x18\x02 \x01(\x04\x12O\n\x0bProxyStates\x18\x03 \x03(\x0b\x32:.NKikimrSchemeBoardMon.TSubscriberResponse.TProxyStateInfo\x12\x44\n\x05State\x18\x04 \x01(\x0b\x32\x35.NKikimrSchemeBoardMon.TSubscriberResponse.TStateInfo\x12\x1a\n\x12\x44\x65layedSyncRequest\x18\x05 \x01(\x04\x12\x1a\n\x12\x43urrentSyncRequest\x18\x06 \x01(\x04\x12\x0e\n\x04Path\x18\x07 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x08 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x1a\xbf\x01\n\nTStateInfo\x12\x0f\n\x07\x44\x65leted\x18\x01 \x01(\x08\x12\x0e\n\x06Strong\x18\x02 \x01(\x08\x12.\n\x06PathId\x18\x03 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x0f\n\x07Version\x18\x04 \x01(\x04\x12\x30\n\x08\x44omainId\x18\x05 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x1d\n\x15\x41\x62\x61ndonedSchemeShards\x18\x06 \x03(\x04\x1a~\n\x0fTProxyStateInfo\x12%\n\x05Proxy\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x44\n\x05State\x18\x02 \x01(\x0b\x32\x35.NKikimrSchemeBoardMon.TSubscriberResponse.TStateInfoB\n\n\x08PathKind\"\x9f\x02\n\x18TSubscriberProxyResponse\x12&\n\x06Parent\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\'\n\x07Replica\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x31\n\x11ReplicaSubscriber\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x15\n\rDomainOwnerId\x18\x04 \x01(\x04\x12\x1a\n\x12\x43urrentSyncRequest\x18\x05 \x01(\x04\x12\x0e\n\x04Path\x18\x06 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x07 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"\xee\x01\n\x1aTReplicaSubscriberResponse\x12&\n\x06Parent\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\'\n\x07Replica\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x15\n\rDomainOwnerId\x18\x03 \x01(\x04\x12\x1a\n\x12\x43urrentSyncRequest\x18\x04 \x01(\x04\x12\x0e\n\x04Path\x18\x05 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x06 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"_\n\x0eTCacheResponse\x12\x17\n\x0fItemsTotalCount\x18\x01 \x01(\x04\x12\x18\n\x10ItemsByPathCount\x18\x02 \x01(\x04\x12\x1a\n\x12ItemsByPathIdCount\x18\x03 \x01(\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_board_mon_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVINFOREQUEST._serialized_start=105
  _TEVINFOREQUEST._serialized_end=156
  _TEVINFORESPONSE._serialized_start=159
  _TEVINFORESPONSE._serialized_end=816
  _TEVDESCRIBEREQUEST._serialized_start=818
  _TEVDESCRIBEREQUEST._serialized_end=916
  _TEVDESCRIBERESPONSE._serialized_start=918
  _TEVDESCRIBERESPONSE._serialized_end=953
  _TPATHID._serialized_start=955
  _TPATHID._serialized_end=1002
  _TREPLICARESPONSE._serialized_start=1005
  _TREPLICARESPONSE._serialized_end=1603
  _TREPLICARESPONSE_TPOPULATORINFO._serialized_start=1260
  _TREPLICARESPONSE_TPOPULATORINFO._serialized_end=1379
  _TREPLICARESPONSE_TDESCRIPTIONSINFO._serialized_start=1381
  _TREPLICARESPONSE_TDESCRIPTIONSINFO._serialized_end=1464
  _TREPLICARESPONSE_TSUBSCRIBERINFO._serialized_start=1467
  _TREPLICARESPONSE_TSUBSCRIBERINFO._serialized_end=1603
  _TPOPULATORRESPONSE._serialized_start=1606
  _TPOPULATORRESPONSE._serialized_end=2160
  _TPOPULATORRESPONSE_TUPDATEACKINFO._serialized_start=1900
  _TPOPULATORRESPONSE_TUPDATEACKINFO._serialized_end=2160
  _TPOPULATORRESPONSE_TUPDATEACKINFO_TPATHACKINFO._serialized_start=2062
  _TPOPULATORRESPONSE_TUPDATEACKINFO_TPATHACKINFO._serialized_end=2160
  _TREPLICAPOPULATORRESPONSE._serialized_start=2163
  _TREPLICAPOPULATORRESPONSE._serialized_end=2916
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO._serialized_start=2714
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO._serialized_end=2916
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO_TVERSIONINFO._serialized_start=2870
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO_TVERSIONINFO._serialized_end=2916
  _TSUBSCRIBERRESPONSE._serialized_start=2919
  _TSUBSCRIBERRESPONSE._serialized_end=3609
  _TSUBSCRIBERRESPONSE_TSTATEINFO._serialized_start=3278
  _TSUBSCRIBERRESPONSE_TSTATEINFO._serialized_end=3469
  _TSUBSCRIBERRESPONSE_TPROXYSTATEINFO._serialized_start=3471
  _TSUBSCRIBERRESPONSE_TPROXYSTATEINFO._serialized_end=3597
  _TSUBSCRIBERPROXYRESPONSE._serialized_start=3612
  _TSUBSCRIBERPROXYRESPONSE._serialized_end=3899
  _TREPLICASUBSCRIBERRESPONSE._serialized_start=3902
  _TREPLICASUBSCRIBERRESPONSE._serialized_end=4140
  _TCACHERESPONSE._serialized_start=4142
  _TCACHERESPONSE._serialized_end=4237
# @@protoc_insertion_point(module_scope)



import ydb.apps.dstool.lib.common as common
import sys

description = 'Remove vdisks that are in donor mode'


def add_options(p):
    common.add_vdisk_ids_option(p, required=True)
    common.add_basic_format_options(p)


def create_request(args):
    base_config = common.fetch_base_config()
    vslots = common.get_vslots_by_vdisk_ids(base_config, args.vdisk_ids)
    request = common.kikimr_bsconfig.TConfigRequest(Rollback=args.dry_run)
    for vslot in vslots:
        for donor in vslot.Donors:
            cmd = request.Command.add().DropDonorDisk
            cmd.VSlotId.CopyFrom(donor.VSlotId)
            cmd.VDiskId.CopyFrom(donor.VDiskId)

    return request


def perform_request(request):
    return common.invoke_bsc_request(request)


def is_successful_response(response):
    return common.is_successful_bsc_response(response)


def do(args):
    request = create_request(args)
    response = perform_request(request)
    common.print_request_result(args, request, response)
    if not is_successful_response(response):
        sys.exit(1)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/bind_channel_storage_pool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ydb/core/protos/bind_channel_storage_pool.proto\x12\x12NKikimrStoragePool\"*\n\x0cTStoragePool\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Kind\x18\x02 \x01(\t\"s\n\x0cTChannelBind\x12\x17\n\x0fStoragePoolName\x18\x02 \x01(\t\x12\x0c\n\x04IOPS\x18\n \x01(\x02\x12\x12\n\nThroughput\x18\x0b \x01(\x04\x12\x0c\n\x04Size\x18\x0c \x01(\x04\x12\x1a\n\x12PhysicalGroupsOnly\x18\x14 \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.bind_channel_storage_pool_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSTORAGEPOOL._serialized_start=71
  _TSTORAGEPOOL._serialized_end=113
  _TCHANNELBIND._serialized_start=115
  _TCHANNELBIND._serialized_end=230
# @@protoc_insertion_point(module_scope)
